#!/usr/bin/env python
# -*- coding: utf-8 -*-
import logging
try:
    from oss2 import Auth, Bucket
except ImportError:
    raise RuntimeError('Unable to import qiniu module. Install by running pip install oss2')
from pywkcloud.storage import StoreConfig, StorageBase
logger = logging.getLogger('OSSUtils')


class OSSUtils(StorageBase):

    def __init__(self, store_config: StoreConfig):
        super(OSSUtils, self).__init__(store_config)

    def get_auth(self):
        if not self._auth:
            self._auth = Auth(self._store_config.access_key, self._store_config.secret_key)
        return self._auth
    
    def _Bucket(self):
        q = self.get_auth()
        return Bucket(q, self._store_config.endpoint, self._store_config.bucket_name)

    def check_bucket(self, key):
        bucket = self._Bucket()
        logger.debug(key)
        # 获取文件的状态信息
        return bucket.object_exists(key)

    def upload_file(self, key, file_path):
        bucket = self._Bucket()
        ret = bucket.put_object_from_file(key, file_path, None, None)
        logger.debug(ret)
        return ret

    def delete_file(self, key):
        bucket = self._Bucket()
        ret = bucket.delete_object(key, params=None, headers=None)
        logger.debug(ret)
        return ret

    def get_file(self, key, filename):
        bucket = self._Bucket()
        return bucket.get_object_to_file(key, filename, None, None, None, None, None)


if __name__ == '__main__':
    pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
from pywkmisc import FileUtils, get_config


class StoreConfig(object):

    def __init__(self, config_name=None, config=None):
        if config_name:
            config = get_config(config_name)
        if not config:
            raise RuntimeError('''找不到参数，请配置参数，样例:
            {
                "accessKey": "",            #
                "secretKey": "",            #
                "bucketName": "",           # oss endpoint
                "endpoint": "",            # 连接的bucket地址
                "connectionTimeout": 120     # 连接超时时间，120秒为2分钟
                "defaultZone": ""           # 系统默认连接地址
            }''')

        self._access_key = config.get('accessKey')
        self._secret_key = config.get('secretKey')
        self._bucket_name = config.get('bucketName')
        self._endpoint = config.get('endpoint')
        self._connection_timeout = config.get('connectionTimeout', 120)
        self._default_zone = config.get('defaultZone')

    @property
    def access_key(self):
        return self._access_key

    @property
    def secret_key(self):
        return self._secret_key

    @property
    def bucket_name(self):
        return self._bucket_name

    @property
    def endpoint(self):
        return self._endpoint

    @property
    def connection_timeout(self):
        return self._connection_timeout

    @property
    def default_zone(self):
        return self._default_zone


class StorageBase(object):
    
    def __init__(self, store_config: StoreConfig):
        self._store_config = store_config
        self._auth = None

    def get_auth(self):
        """
        获取凭证
        :return:
        """

    def check_bucket(self, key):
        """
        判断文件是否存在
        :param key:文件key
        :return True文件存在，False文件不存在
        """

    def upload_file(self, key, upload_file: FileUtils):
        """
        上传文件至oss
        :param key:         上传文件的key值
        :param upload_file:   文件路径
        :return:
        """

    def delete_file(self, key):
        """
        删除文件
        :param key:         上传文件的key值
        :return:
        """

    def get_file(self, key, filename: FileUtils):
        """
        下载一个文件到本地文件。
        :param key: 文件名
        :param filename: 本地文件名。要求父目录已经存在，且有写权限。
        :return: 如果文件不存在，则抛出 :class:`NoSuchKey <oss2.exceptions.NoSuchKey>` ；还可能抛出其他异常
        """



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import logging
try:
    from qiniu import Auth, put_file, zone, config, BucketManager
except ImportError:
    raise RuntimeError('Unable to import qiniu module. Install by running '
                       'pip install qiniu')

from pywkcloud.storage import StoreConfig, StorageBase
logger = logging.getLogger('KodoUtils')


class KodoUtils(StorageBase):

    def __init__(self, store_config: StoreConfig):
        super(KodoUtils, self).__init__(store_config)

    def get_auth(self):
        if not self._auth:
            config.set_default(connection_timeout=self._store_config.connection_timeout)
            if self._store_config.default_zone:
                config.set_default(default_zone=zone.Zone(up_host=self._store_config.default_zone))
            self._auth = Auth(self._store_config.access_key, self._store_config.secret_key)
        return self._auth

    def check_bucket(self, key):
        logger.debug(key)
        bucket = BucketManager(self.get_auth())
        ret, info = bucket.stat(self._store_config.bucket_name, key)
        logger.debug(info)
        if info.status_code == 200:
            return True
        else:
            return False

    def upload_file(self, key, file_path):
        logger.debug(key)
        q = self.get_auth()
        token = q.upload_token(self._store_config.bucket_name, key, 3600)
        ret, info = put_file(token, key, file_path)
        logger.debug(ret)
        logger.debug(info)
        return ret, info

    def delete_file(self, key):
        q = self.get_auth()
        bucket = BucketManager(q)
        ret, info = bucket.delete(self._store_config.bucket_name, key)
        logger.debug(ret)
        logger.debug(info)
        return ret, info

    def get_file(self, key, filename):
        from pywkmisc import HttpClientUtils
        q = self.get_auth()
        base_url = 'http://{bucket_domain}/{key}'.format(bucket_domain=self._store_config.endpoint, key=key)
        private_url = q.private_download_url(base_url)
        logger.debug(private_url)
        return HttpClientUtils.save_file(private_url, filename)


if __name__ == '__main__':
    pass
